export class GameRules {
    static isValidPlay(currentCard, playedCard) {
        return playedCard.matches(currentCard);
    }
    static getDrawCount(card) {
        switch (card.getValue()) {
            case "draw_2":
                return 2;
            case "wild_draw_4":
                return 4;
            default:
                return 0;
        }
    }
    static getNextPosition(currentPosition, playerCount, isReverse) {
        if (isReverse) {
            return currentPosition === 1 ? playerCount : currentPosition - 1;
        }
        return currentPosition === playerCount ? 1 : currentPosition + 1;
    }
    static getSkipPosition(currentPosition, playerCount) {
        return this.getNextPosition(this.getNextPosition(currentPosition, playerCount, false), playerCount, false);
    }
    static canPlayAnyCard(player, currentCard) {
        return player
            .getCards()
            .some((card) => this.isValidPlay(currentCard, card));
    }
    static calculatePoints(player) {
        return player.getCards().reduce((sum, card) => sum + card.getPoints(), 0);
    }
    static isGameOver(game) {
        const players = game.getPlayers();
        return players.some((player) => player.getCards().length === 0);
    }
    static getWinner(players) {
        const winner = players.find((player) => player.getCards().length === 0);
        return winner || null;
    }
}
//# sourceMappingURL=GameRules.js.map